==> torchcvnn-0.7.0.tar.gz: torchcvnn-0.7.0/src/torchcvnn/nn/modules/__init__.py <==
# MIT License

# Copyright (c) 2023 Jérémie Levi, Victor Dhédin, Jeremy Fix

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from .pooling import MaxPool2d, AvgPool2d
from .dropout import Dropout, Dropout2d
from .conv import ConvTranspose2d
from .batchnorm import BatchNorm1d, BatchNorm2d
from .upsampling import Upsample
from .normalization import LayerNorm
from . import initialization as init
from .loss import ComplexMSELoss
from .activation import (
    CReLU,
    CPReLU,
    CELU,
    CCELU,
    CGELU,
    CSigmoid,
    CTanh,
    zReLU,
    zAbsReLU,
    zLeakyReLU,
    Mod,
    modReLU,
    Cardioid,
)

==> torchcvnn-0.9.6.tar.gz: torchcvnn-0.9.6/src/torchcvnn/nn/modules/__init__.py <==
# MIT License

# Copyright (c) 2023 Jérémie Levi, Victor Dhédin, Jeremy Fix

# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:

# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.

# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.

from .pooling import MaxPool2d, AvgPool2d
from .dropout import Dropout, Dropout2d
from .conv import ConvTranspose2d
from .batchnorm import BatchNorm1d, BatchNorm2d
from .upsampling import Upsample
from .normalization import LayerNorm, RMSNorm
from .transformer import (
    TransformerEncoder,
    TransformerEncoderLayer,
    TransformerDecoderLayer,
    Transformer,
)
from .vit import ViTLayer, ViT
from . import initialization as init
from .loss import ComplexMSELoss
from .activation import (
    CReLU,
    CPReLU,
    CELU,
    CCELU,
    CGELU,
    CSigmoid,
    CTanh,
    zReLU,
    zAbsReLU,
    zLeakyReLU,
    Mod,
    modReLU,
    Cardioid,
    MultiheadAttention,
)
